@@ -41,7 +41,7 @@ ob_implicit_flush(true);
 $_PEAR_PHPDIR = '#$%^&*';
 set_error_handler('error_handler');
 
-$pear_package_version = "1.10.5";
+$pear_package_version = "1.10.9";
 
 require_once 'PEAR.php';
 require_once 'PEAR/Frontend.php';
@@ -438,26 +438,23 @@ function cmdHelp($command)
  * @param mixed $errmsg Message
  * @param mixed $file   Filename
  * @param mixed $line   Line number
- * @param mixed $vars   Variables
  *
  * @access public
  * @return boolean
  */
-function error_handler($errno, $errmsg, $file, $line, $vars)
+function error_handler($errno, $errmsg, $file, $line)
 {
-    if ($errno & E_STRICT
-        || $errno & E_DEPRECATED
-        || !error_reporting()
+    if ($errno & E_STRICT) {
+        return; // E_STRICT
+    }
+    if ($errno & E_DEPRECATED) {
+        return; // E_DEPRECATED
+    }
+    if (!(error_reporting() & $errno) &&
+        isset($GLOBALS['config']) &&
+        $GLOBALS['config']->get('verbose') < 4
     ) {
-        if ($errno & E_STRICT) {
-            return; // E_STRICT
-        }
-        if ($errno & E_DEPRECATED) {
-            return; // E_DEPRECATED
-        }
-        if (!error_reporting() && isset($GLOBALS['config']) && $GLOBALS['config']->get('verbose') < 4) {
-            return false; // @silenced error, show all if debug is high enough
-        }
+        return false; // @silenced error, show all if debug is high enough
     }
     $errortype = array (
         E_DEPRECATED  => 'Deprecated Warning',
